#------------------------------------------------
# Gnuplot file for pdf, cdf, and ccdf generation
# of fitted distributions and trace data
#------------------------------------------------

# general settings
set noparametric
set border
set grid

#--------------------------------------------------------------------------------------

# settings for the pdf
set title "Probability density functions"
set xlabel "x"
set ylabel "pdf"

set xrange [0.0:2.0]
set autoscale y
set terminal postscript landscape "Times-Roman" 18
set output "./curves/pdf.ps"
set multiplot

plot \
"curves/trace_pdf.dat" using 1:2 title "Empirical distribution of trace" with lines, \
"curves/gfit.dat" using 1:2 title "Fitted hyper-Erlang distribution" with linespoints

set nomultiplot

#--------------------------------------------------------------------------------------

# settings for the cdf
set title "Cumulative distribution functions"
set xlabel "x"
set ylabel "cdf"

set xrange [0.0:2.0]
set yrange [0.0:1.0]

set terminal postscript landscape "Times-Roman" 18
set output "./curves/cdf.ps"

set multiplot

plot \
"curves/trace_cdf.dat" using 1:2 title "Empirical distribution of trace" with lines, \
"curves/gfit.dat" using 1:3 title "Fitted hyper-Erlang distribution" with linespoints

set nomultiplot

#--------------------------------------------------------------------------------------

# settings for the ccdf
set title "Complementary cumulative distribution functions"
set xlabel "x"
set ylabel "ccdf"

set autoscale x
set yrange [1e-5:1.0]
set logscale x 10
set logscale y 10

set terminal postscript landscape "Times-Roman" 18
set output "./curves/ccdf.ps"

set multiplot

plot \
"curves/trace_ccdf.dat" using 1:2 title "Empirical distribution of trace" with lines, \
"curves/gfit.dat" using 1:4 title "Fitted hyper-Erlang distribution" with lines

set nomultiplot
set nologscale

#--------------------------------------------------------------------------------------

# settings for the convergence curve
set title "Convergence behavior of EM algorithm"
set xlabel "Iteration No."
set ylabel "Relative difference"

set autoscale xy
set logscale y

set terminal postscript landscape "Times-Roman" 18
set output "./curves/conv.ps"

set multiplot

plot \
"curves/conv.dat" using 1:2 title "Relative difference of log-likelihood values" with lines

set nomultiplot
