/****************************************************************************/
/** G-FIT V1.0                                                             **/
/** Fitting hyper-Erlang distributions to trace data with the EM algorithm **/
/**                                                                        **/
/** Developed by Axel Thuemmler, July/August 2004                          **/
/** Copyright (c) 2004 University of Dortmund. All rights reserved.        **/
/**                                                                        **/
/** The G-FIT software package is distributed in open-source under the     **/
/** terms of the GNU general public license agreement. To document the     **/
/** usage of G-FIT, we ask each user to cite our scientific publications   **/
/** mentioned on our Web site.                                             **/
/****************************************************************************/
#ifndef GERLANGFIT_H
#define GERLANGFIT_H

#include <fstream>

#include "gerlangdist.h"
#include "queue.h"


enum TConvCheck {PAR_DIFF, LLH_DIFF};

//---------------------
// Definition of class
//---------------------
class TGerlangFit
{

	public:

		TGerlangFit(TTrace* _trace, double _eps, TConvCheck _conv_check);

		~TGerlangFit();

		void fit(TGerlangDist* gdist);

		void fit_adaptive(TGerlangDist* gdist, unsigned int steps);

		void fit_all(TGerlangDist* gdist, unsigned int N, unsigned int m_min, unsigned int m_max);

		void fit_all_steps(TGerlangDist* gdist, unsigned int N, unsigned int m_min, unsigned int m_max);

		unsigned long get_num_settings(unsigned int N, unsigned int m_min, unsigned int m_max);

		unsigned long get_count();
		
		double get_max_diff();

	private:
	
		void fit_base(TGerlangDist* gdist);

		void fit_all_base(TGerlangDist* gdist, unsigned int N, unsigned int m_min, unsigned int m_max);

		void fit_settings(unsigned int m, unsigned int N, unsigned int k, unsigned int* r, unsigned int pos, TGerlangDist* gdist);

		double contrib(TGerlangDist* gdist, unsigned int i);

		unsigned long calc_num_settings(unsigned int m, unsigned int N, unsigned int k);

		unsigned long enum_settings(unsigned int m, unsigned int N, unsigned int k, unsigned int* r, unsigned int pos);


		// counts the number of iterations of the EM algorithm
		unsigned long count;

		TConvCheck conv_check;

		double max_diff;

		double eps;

		TTrace* trace;

		// pointers to arrays of lambda-values and weights
		double** lptr;
		double** wptr;

		// pointers to temporary memory with pre-computed value (allows faster iterations)
		double *tmp1;
		double *tmp2;

		// priority queue with best fitted hyper-Erlang distribution (required by fit_all)
		TQueue* queue;

		// pointers to logfile and file with convergence behavior
		std::ofstream* glog;
		std::ofstream* conv;

};

#endif
