/****************************************************************************/
/** G-FIT V1.0                                                             **/
/** Fitting hyper-Erlang distributions to trace data with the EM algorithm **/
/**                                                                        **/
/** Developed by Axel Thuemmler, July/August 2004                          **/
/** Copyright (c) 2004 University of Dortmund. All rights reserved.        **/
/**                                                                        **/
/** The G-FIT software package is distributed in open-source under the     **/
/** terms of the GNU general public license agreement. To document the     **/
/** usage of G-FIT, we ask each user to cite our scientific publications   **/
/** mentioned on our Web site.                                             **/
/****************************************************************************/
#ifndef TRACE_H
#define TRACE_H

#define TRACE_PDF_FILENAME		"./curves/trace_pdf.dat"
#define TRACE_CDF_FILENAME		"./curves/trace_cdf.dat"
#define TRACE_CCDF_FILENAME		"./curves/trace_ccdf.dat"


typedef struct tagTTraceStatistics
{
	double m[5];	// first five moments
	double var;		// variance
	double cvs;		// squared coefficient of variation
	double min;		// minimum
	double max;		// maximum
} TTraceStatistics;


class TTrace
{

	public:

		// Constructors
		TTrace();
		TTrace(double* _trace, unsigned long _size);

		// Destructor
		~TTrace();

		void init(double* _trace, unsigned long _size);

		// Read trace from file
		void read_file(const char* filename);

		// Write trace to file
		void write_file(const char* filename, bool with_size = true);

		// Sort trace from smallest to largest value
		double sort();

		// Compute statistics of empirical distribution from trace data
		void compute_distribution( double , unsigned int );
		void compute_statistics();

		unsigned long get_size();
		double get_element(unsigned int i);

		void scale(double mean);

		TTraceStatistics get_statistics();

	private:
	
		unsigned long size;

		double* trace;

		TTraceStatistics statistics;
		
	friend class TGerlangDist;
	friend class TGerlangFit;

};


#endif
